import { Message, Pattern } from '@fluent/bundle/esm/ast';
import { FluentBundle, FluentVariable } from '@fluent/bundle';
import { Ref } from 'vue-demi';

type SimpleNode = Pick<Node, 'nodeType' | 'textContent' | 'nodeValue'>

interface FluentVueOptions {
  /** Current negotiated fallback chain of languages */
  bundles: Iterable<FluentBundle>

  /** Custom function for warning about missing translation */
  warnMissing?: ((key: string) => void) | boolean

  /** Custom function for parsing markup */
  parseMarkup?: (markup: string) => SimpleNode[]
}

interface TranslationContextOptions {
  warnMissing: (key: string) => void
  parseMarkup: (markup: string) => SimpleNode[]
}

interface TranslationWithAttrs {
    value: string;
    hasValue: boolean;
    attributes: Record<string, string>;
}
declare class TranslationContext {
    options: TranslationContextOptions;
    bundles: Ref<Iterable<FluentBundle>>;
    constructor(bundles: Ref<Iterable<FluentBundle>>, options: TranslationContextOptions);
    getBundle(key: string): FluentBundle | null;
    getMessage(bundle: FluentBundle | null, key: string): Message | null;
    formatPattern(bundle: FluentBundle, key: string, message: Pattern, value?: Record<string, FluentVariable>): string;
    private _format;
    format: (key: string, value?: Record<string, FluentVariable>) => string;
    private _formatAttrs;
    formatAttrs: (key: string, value?: Record<string, FluentVariable>) => Record<string, string>;
    formatWithAttrs: (key: string, value?: Record<string, FluentVariable>) => TranslationWithAttrs;
    $t: (key: string, value?: Record<string, FluentVariable>) => string;
    $ta: (key: string, value?: Record<string, FluentVariable>) => Record<string, string>;
}

declare function useFluent(): TranslationContext;

export { FluentVueOptions as F, TranslationWithAttrs as T, useFluent as u };
